@@ -76,7 +76,9 @@ impl Copyright {
     pub fn iter_licenses(&self) -> impl Iterator<Item = LicenseParagraph> {
         self.0
             .paragraphs()
-            .filter(|x| !x.contains_key("Files") && x.contains_key("License"))
+            .filter(|x| {
+                !x.contains_key("Files") && !x.contains_key("Format") && x.contains_key("License")
+            })
             .map(LicenseParagraph)
     }
 
@@ -129,6 +131,94 @@ impl Copyright {
         use std::str::FromStr;
         Self::from_str(&text)
     }
+
+    /// Add a new files paragraph
+    ///
+    /// Returns a mutable reference to the newly created FilesParagraph
+    pub fn add_files(
+        &mut self,
+        files: &[&str],
+        copyright: &[&str],
+        license: &License,
+    ) -> FilesParagraph {
+        let mut para = self.0.add_paragraph();
+        para.set("Files", &files.join(" "));
+        para.set("Copyright", &copyright.join("\n"));
+        let license_text = match license {
+            License::Name(name) => name.to_string(),
+            License::Named(name, text) => format!("{}\n{}", name, text),
+            License::Text(text) => text.to_string(),
+        };
+        para.set("License", &license_text);
+        FilesParagraph(para)
+    }
+
+    /// Add a new license paragraph
+    ///
+    /// Returns a mutable reference to the newly created LicenseParagraph
+    pub fn add_license(&mut self, license: &License) -> LicenseParagraph {
+        let mut para = self.0.add_paragraph();
+        let license_text = match license {
+            License::Name(name) => name.to_string(),
+            License::Named(name, text) => format!("{}\n{}", name, text),
+            License::Text(text) => text.to_string(),
+        };
+        para.set("License", &license_text);
+        LicenseParagraph(para)
+    }
+
+    /// Remove a license paragraph by its short name
+    ///
+    /// This removes the first standalone license paragraph that matches the given name.
+    /// Returns true if a paragraph was removed, false otherwise.
+    pub fn remove_license_by_name(&mut self, name: &str) -> bool {
+        // Find the index of the license paragraph
+        let mut index = None;
+        for (i, para) in self.0.paragraphs().enumerate() {
+            if !para.contains_key("Files")
+                && !para.contains_key("Format")
+                && para.contains_key("License")
+            {
+                let license_para = LicenseParagraph(para);
+                if license_para.name().as_deref() == Some(name) {
+                    index = Some(i);
+                    break;
+                }
+            }
+        }
+
+        if let Some(i) = index {
+            self.0.remove_paragraph(i);
+            true
+        } else {
+            false
+        }
+    }
+
+    /// Remove a files paragraph by matching file pattern
+    ///
+    /// This removes the first files paragraph where the Files field contains the given pattern.
+    /// Returns true if a paragraph was removed, false otherwise.
+    pub fn remove_files_by_pattern(&mut self, pattern: &str) -> bool {
+        // Find the index of the files paragraph
+        let mut index = None;
+        for (i, para) in self.0.paragraphs().enumerate() {
+            if para.contains_key("Files") {
+                let files_para = FilesParagraph(para);
+                if files_para.files().iter().any(|f| f == pattern) {
+                    index = Some(i);
+                    break;
+                }
+            }
+        }
+
+        if let Some(i) = index {
+            self.0.remove_paragraph(i);
+            true
+        } else {
+            false
+        }
+    }
 }
 
 /// Error parsing copyright files
@@ -606,4 +696,242 @@ License: GPL-3+
         assert_eq!(license.name().unwrap(), "MIT");
         assert_eq!(license.text().unwrap(), "Permission is hereby granted...");
     }
+
+    #[test]
+    fn test_iter_licenses_excludes_header() {
+        // Test that iter_licenses does not include the header paragraph even if it has a License field
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Upstream-Name: foo
+License: GPL-3+
+
+Files: *
+Copyright: 2020 Joe Bloggs
+License: MIT
+
+License: GPL-3+
+ This is the GPL-3+ license text.
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let licenses: Vec<_> = copyright.iter_licenses().collect();
+
+        // Should only have the standalone License paragraph, not the header
+        assert_eq!(1, licenses.len());
+        assert_eq!("GPL-3+", licenses[0].name().unwrap());
+        assert_eq!(
+            "This is the GPL-3+ license text.",
+            licenses[0].text().unwrap()
+        );
+    }
+
+    #[test]
+    fn test_add_files() {
+        let mut copyright = super::Copyright::new();
+        let license = crate::License::Name("GPL-3+".to_string());
+        copyright.add_files(
+            &["src/*", "*.rs"],
+            &["2024 John Doe", "2024 Jane Doe"],
+            &license,
+        );
+
+        let files: Vec<_> = copyright.iter_files().collect();
+        assert_eq!(1, files.len());
+        assert_eq!(vec!["src/*", "*.rs"], files[0].files());
+        assert_eq!(vec!["2024 John Doe", "2024 Jane Doe"], files[0].copyright());
+        assert_eq!("GPL-3+", files[0].license().unwrap().name().unwrap());
+
+        // Verify the generated format
+        assert_eq!(
+            copyright.to_string(),
+            "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\n\
+             Copyright: 2024 John Doe\n           2024 Jane Doe\n\
+             Files: src/* *.rs\n\
+             License: GPL-3+\n"
+        );
+    }
+
+    #[test]
+    fn test_add_files_with_license_text() {
+        let mut copyright = super::Copyright::new();
+        let license = crate::License::Named(
+            "MIT".to_string(),
+            "Permission is hereby granted...".to_string(),
+        );
+        copyright.add_files(&["*"], &["2024 Test Author"], &license);
+
+        let files: Vec<_> = copyright.iter_files().collect();
+        assert_eq!(1, files.len());
+        assert_eq!("MIT", files[0].license().unwrap().name().unwrap());
+        assert_eq!(
+            "Permission is hereby granted...",
+            files[0].license().unwrap().text().unwrap()
+        );
+
+        // Verify the generated format
+        assert_eq!(
+            copyright.to_string(),
+            "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\n\
+             Copyright: 2024 Test Author\n\
+             Files: *\n\
+             License: MIT\n         Permission is hereby granted...\n"
+        );
+    }
+
+    #[test]
+    fn test_add_license() {
+        let mut copyright = super::Copyright::new();
+        let license = crate::License::Named(
+            "GPL-3+".to_string(),
+            "This is the GPL-3+ license text.".to_string(),
+        );
+        copyright.add_license(&license);
+
+        let licenses: Vec<_> = copyright.iter_licenses().collect();
+        assert_eq!(1, licenses.len());
+        assert_eq!("GPL-3+", licenses[0].name().unwrap());
+        assert_eq!(
+            "This is the GPL-3+ license text.",
+            licenses[0].text().unwrap()
+        );
+
+        // Verify the generated format
+        assert_eq!(
+            copyright.to_string(),
+            "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\n\
+             License: GPL-3+\n         This is the GPL-3+ license text.\n"
+        );
+    }
+
+    #[test]
+    fn test_add_multiple_paragraphs() {
+        let mut copyright = super::Copyright::new();
+
+        // Add a files paragraph
+        let license1 = crate::License::Name("MIT".to_string());
+        copyright.add_files(&["src/*"], &["2024 Author One"], &license1);
+
+        // Add another files paragraph
+        let license2 = crate::License::Name("GPL-3+".to_string());
+        copyright.add_files(&["debian/*"], &["2024 Author Two"], &license2);
+
+        // Add a license paragraph
+        let license3 =
+            crate::License::Named("GPL-3+".to_string(), "Full GPL-3+ text here.".to_string());
+        copyright.add_license(&license3);
+
+        // Verify all paragraphs were added
+        assert_eq!(2, copyright.iter_files().count());
+        assert_eq!(1, copyright.iter_licenses().count());
+
+        let files: Vec<_> = copyright.iter_files().collect();
+        assert_eq!(vec!["src/*"], files[0].files());
+        assert_eq!(vec!["debian/*"], files[1].files());
+
+        let licenses: Vec<_> = copyright.iter_licenses().collect();
+        assert_eq!("GPL-3+", licenses[0].name().unwrap());
+        assert_eq!("Full GPL-3+ text here.", licenses[0].text().unwrap());
+
+        // Verify the generated format
+        assert_eq!(
+            copyright.to_string(),
+            "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\n\
+             Copyright: 2024 Author One\n\
+             Files: src/*\n\
+             License: MIT\n\n\
+             Copyright: 2024 Author Two\n\
+             Files: debian/*\n\
+             License: GPL-3+\n\n\
+             License: GPL-3+\n         Full GPL-3+ text here.\n"
+        );
+    }
+
+    #[test]
+    fn test_remove_license_by_name() {
+        let mut copyright = super::Copyright::new();
+
+        // Add multiple license paragraphs
+        let license1 = crate::License::Named("MIT".to_string(), "MIT license text.".to_string());
+        copyright.add_license(&license1);
+
+        let license2 =
+            crate::License::Named("GPL-3+".to_string(), "GPL-3+ license text.".to_string());
+        copyright.add_license(&license2);
+
+        let license3 =
+            crate::License::Named("Apache-2.0".to_string(), "Apache license text.".to_string());
+        copyright.add_license(&license3);
+
+        // Verify we have 3 license paragraphs
+        assert_eq!(3, copyright.iter_licenses().count());
+
+        // Remove the GPL-3+ license
+        let removed = copyright.remove_license_by_name("GPL-3+");
+        assert!(removed);
+
+        // Verify we now have 2 license paragraphs
+        assert_eq!(2, copyright.iter_licenses().count());
+
+        // Verify the remaining licenses
+        let licenses: Vec<_> = copyright.iter_licenses().collect();
+        assert_eq!("MIT", licenses[0].name().unwrap());
+        assert_eq!("Apache-2.0", licenses[1].name().unwrap());
+
+        // Try to remove a non-existent license
+        let removed = copyright.remove_license_by_name("BSD-3-Clause");
+        assert!(!removed);
+        assert_eq!(2, copyright.iter_licenses().count());
+    }
+
+    #[test]
+    fn test_remove_files_by_pattern() {
+        let mut copyright = super::Copyright::new();
+
+        // Add multiple files paragraphs
+        let license1 = crate::License::Name("MIT".to_string());
+        copyright.add_files(&["src/*"], &["2024 Author One"], &license1);
+
+        let license2 = crate::License::Name("GPL-3+".to_string());
+        copyright.add_files(&["debian/*"], &["2024 Author Two"], &license2);
+
+        let license3 = crate::License::Name("Apache-2.0".to_string());
+        copyright.add_files(&["docs/*"], &["2024 Author Three"], &license3);
+
+        // Verify we have 3 files paragraphs
+        assert_eq!(3, copyright.iter_files().count());
+
+        // Remove the debian/* files paragraph
+        let removed = copyright.remove_files_by_pattern("debian/*");
+        assert!(removed);
+
+        // Verify we now have 2 files paragraphs
+        assert_eq!(2, copyright.iter_files().count());
+
+        // Verify the remaining files paragraphs
+        let files: Vec<_> = copyright.iter_files().collect();
+        assert_eq!(vec!["src/*"], files[0].files());
+        assert_eq!(vec!["docs/*"], files[1].files());
+
+        // Try to remove a non-existent pattern
+        let removed = copyright.remove_files_by_pattern("tests/*");
+        assert!(!removed);
+        assert_eq!(2, copyright.iter_files().count());
+    }
+
+    #[test]
+    fn test_remove_files_by_pattern_with_multiple_patterns() {
+        let mut copyright = super::Copyright::new();
+
+        // Add a files paragraph with multiple patterns
+        let license = crate::License::Name("MIT".to_string());
+        copyright.add_files(&["src/*", "*.rs"], &["2024 Author"], &license);
+
+        // Verify we have 1 files paragraph
+        assert_eq!(1, copyright.iter_files().count());
+
+        // Remove by matching one of the patterns
+        let removed = copyright.remove_files_by_pattern("*.rs");
+        assert!(removed);
+
+        // Verify the paragraph was removed
+        assert_eq!(0, copyright.iter_files().count());
+    }
 }
